@@ -5,11 +5,11 @@
 set_or_print_url()
 {
   # Verify requirements
-  [[ -n "${arg_U}" && -n "${arg_D:-${arg_p:-${arg_P:-${arg_V:-${arg_B}}}}}" ]] &&
+  [[ -n "${arg_U}" && -n "${arg_D:-${arg_p:-${arg_P:-${arg_V}}}}" ]] &&
     emergency "Please pass only one of {-B, -D, -p, -P, -U, -V} or a longer equivalent (multiple detected)."
 
   # Get package name from argument passed with  -p, -D, -P, -V, or -U
-  package_to_build="${arg_p:-${arg_D:-${arg_P:-${arg_U:-${arg_V:-${arg_B}}}}}}"
+  package_to_build="${arg_p:-${arg_D:-${arg_P:-${arg_U:-${arg_V}}}}}"
 
 if [[ -n "${arg_u:-}"  ]]; then
   # User specified a URL from which to download the package
@@ -19,15 +19,9 @@ else
 
   if [[ "${package_to_build}" == 'cmake' ]]; then
     major_minor="${version_to_build%.*}"
-  elif [[ "${package_to_build}" == "gcc" ]]; then
-    if [[ -z "${arg_b:-${arg_B}}" ]]; then
-      gcc_url_head="https://ftpmirror.gnu.org/gcc/gcc-${version_to_build}/"
-    else
-      gcc_url_head="svn://gcc.gnu.org/svn/gcc/"
-    fi
   fi
   package_url_head=(
-    "gcc;${gcc_url_head-}"
+    "gcc;https://gcc.gnu.org/git/"
     "wget;https://ftpmirror.gnu.org/gnu/wget/"
     "m4;https://ftpmirror.gnu.org/gnu/m4/"
     "pkg-config;https://pkgconfig.freedesktop.org/releases/"
@@ -51,19 +45,8 @@ else
   done
 
   # Set differing tails for GCC release downloads versus development branch checkouts
-  if [[ "${package_to_build}" == 'gcc' ]]; then
-    if [[ "${fetch}" == 'svn' ]]; then
-      if [[ "${version_to_build:-}" == "trunk" ]]; then
-        gcc_tail="${version_to_build}"
-      else
-        gcc_tail="branches/${version_to_build:-}"
-      fi
-    else
-      gcc_tail="gcc-${version_to_build}.tar.gz"
-    fi
-  fi
   package_url_tail=(
-    "gcc;${gcc_tail-}"
+    "gcc;gcc"
     "wget;wget-${version_to_build-}.tar.gz"
     "m4;m4-${version_to_build-}.tar.bz2"
     "pkg-config;pkg-config-${version_to_build-}.tar.gz"
