@@ -5,8 +5,8 @@
 # -- Verify whether an OpenCoarrays prerequisite meets the required minimum version number.
 #
 # OpenCoarrays is distributed under the OSI-approved BSD 3-clause License:
-# Copyright (c) 2015-2016, Sourcery, Inc.
-# Copyright (c) 2015-2016, Sourcery Institute
+# Copyright (c) 2015-2020, Sourcery, Inc.
+# Copyright (c) 2015-2020, Sourcery Institute
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without modification,
@@ -44,7 +44,7 @@ this_script=$(basename "$0")
 usage()
 {
     echo ""
-    echo " $this_script - Bash script for verifyin minimum version numbers for OpenCoarrays prerequisites"
+    echo " $this_script - Bash script for verifying minimum version numbers for OpenCoarrays prerequisites"
     echo ""
     echo " Usage (optional arguments in square brackets): "
     echo "      $this_script [<option>]"
@@ -81,11 +81,11 @@ elif [[ $1 == '--list' || $1 == '-l' ]]; then
  exit 40
 
 elif [[ $1 == '-v' || $1 == '-V' || $1 == '--version' ]]; then
-  # Print script copyright if invoked with -v, -V, or --version argument
-  cmake_project_line=$(grep project ../CMakeLists.txt | grep VERSION)
-  text_after_version_keyword="${cmake_project_line##*VERSION}"
-  text_before_language_keyword="${text_after_version_keyword%%LANGUAGES*}"
-  opencoarrays_version=$text_before_language_keyword
+  # Print script copyright if invoked with -v, -V, or --version
+  # argument Extract version from .VERSION file. Git automatically
+  # inserts various things when performing git archive, so ensure we
+  # extract just the first version string
+  opencoarrays_version=$(sed -n '/[0-9]\{1,\}\(\.[0-9]\{1,\}\)\{1,\}/{s/^\([^.]*\)\([0-9]\{1,\}\(\.[0-9]\{1,\}\)\{1,\}\)\(.*\)/\2/p;q;}' ../.VERSION)
   echo "opencoarrays $opencoarrays_version"
   echo ""
   echo "OpenCoarrays prerequisite version verifier"
@@ -104,21 +104,28 @@ if [[ "$verbose" == "--verbose" ]]; then
   echo "$package_version_header"
 fi
 
-# Extract the text after the final space:
-version=${package_version_header##* }
-major=${version%%.*}
-minor_patch=${version#*.}
-minor=${minor_patch%%.*}
-patch=${version##*.}
+before_first_dot="${package_version_header%%.*}"
+major="${before_first_dot##* }" # grab text after final space in remaining string
+
+after_first_dot="${package_version_header#*.}"
+minor="${after_first_dot%%.*}"
+
+after_final_dot="${package_version_header##*.}" # grab text after final dot
+if [[ "$after_final_dot" == "$after_first_dot" ]]; then
+  patch=""
+else
+  patch="${after_final_dot%% *}"
+fi
+
 if [[ "$verbose" == "--verbose" ]]; then
-  echo "$version = $major . $minor . $patch"
+  echo "$major . $minor . $patch"
 fi
 
-# Extract the text after the final space:
 min_major=${minimum_version%%.*}
 min_minor_patch=${minimum_version#*.}
 min_minor=${min_minor_patch%%.*}
 min_patch=${minimum_version##*.}
+
 if [[ "$verbose" == "--verbose" ]]; then
   echo "$minimum_version = $min_major . $min_minor . $min_patch"
 fi
