@@ -23,9 +23,9 @@ program get_offset_1d
 
   if(me == 1) then
     do i=1,10
-      if(b(i) /= 20+i+me+1) call abort()
+      if(b(i) /= 20+i+me+1) error stop "get offset 1d failed"
     enddo
-    write(*,*) 'Test passed.'
   endif
-sync all
+  sync all
+  if(me ==1) write(*,*) 'Test passed.'
 end program
